summaryrefslogtreecommitdiff
path: root/gnu/packages/ssh.scm
diff options
context:
space:
mode:
authorAllan Adair <allan@adair.no>2025-10-06 15:30:38 +0200
committerRutherther <rutherther@ditigal.xyz>2026-01-25 21:24:31 +0100
commit43edd273531e11170c00af395550f57f4815a95a (patch)
tree86455c94dd381f97e5554fc9ebe5adb762961c7a /gnu/packages/ssh.scm
parentfceafe200b8448b407615d75671ff5084f8b050a (diff)
gnu: libssh2: Update to 1.11.1.
* gnu/packages/ssh.scm (libssh2): Update to 1.11.1. [propagated-inputs]: Remove libgcrypt; add openssl. [arguments]: Update #:configure-flags. As per issue https://issues.guix.gnu.org/77154 Closes guix/guix#3349 Change-Id: I109af6a6d42e9e703d0f4e2fd24c0b865d1ceb8f Modified-by: Cayetano Santos <csantosb@inventati.org> Signed-off-by: Cayetano Santos <csantosb@inventati.org> Signed-off-by: Rutherther <rutherther@ditigal.xyz>
Diffstat (limited to 'gnu/packages/ssh.scm')
-rw-r--r--gnu/packages/ssh.scm13
1 files changed, 7 insertions, 6 deletions
diff --git a/gnu/packages/ssh.scm b/gnu/packages/ssh.scm
index e5801109949..0e8076b34b4 100644
--- a/gnu/packages/ssh.scm
+++ b/gnu/packages/ssh.scm
@@ -199,7 +199,7 @@ applications.")
(define-public libssh2
(package
(name "libssh2")
- (version "1.10.0")
+ (version "1.11.1")
(source (origin
(method url-fetch)
(uri (string-append
@@ -207,14 +207,15 @@ applications.")
version ".tar.gz"))
(sha256
(base32
- "0l8xwhhscvss7q007vpbkbv7jh9s43579rx2sf8lnfgd7l7yjr1d"))))
+ "1xsqysmrq40gdfjndd1yrcvwic16kn4jrzir6pn8xfadwg5pdv6r"))))
(build-system gnu-build-system)
;; The installed libssh2.pc file does not include paths to libgcrypt and
;; zlib libraries, so we need to propagate the inputs.
- (propagated-inputs (list libgcrypt zlib))
+ (propagated-inputs (list openssl zlib))
(arguments
- (list #:configure-flags #~'("--with-libgcrypt"
- "--disable-static")))
+ (list #:configure-flags #~'("--with-crypto=openssl"
+ "--disable-static"
+ "--disable-docker-tests")))
(synopsis "Client-side C library implementing the SSH2 protocol")
(description
"libssh2 is a library intended to allow software developers access to
@@ -207,14 +207,15 @@ applications.")
(build-system gnu-build-system)
- ;; The installed libssh2.pc file does not include paths to libgcrypt and
+ ;; The installed libssh2.pc file does not include paths to openssl and
;; zlib libraries, so we need to propagate the inputs.